@@ -555,6 +555,8 @@ GArray* do_cfile_dir(gchar* dir, GError** e) {
 	err_out:
 		if(retval)
 			g_array_free(retval, TRUE);
+		if(dirh)
+			closedir(dirh);
 		return NULL;
 	}
 	return retval;
@@ -1231,7 +1233,11 @@ static void send_reply(uint32_t opt, int net, uint32_t reply_type, size_t datasi
 		{ &datsize, sizeof(datsize) },
 		{ data, datasize },
 	};
-	writev(net, v_data, 5);
+	size_t total = sizeof(magic) + sizeof(opt) + sizeof(reply_type) + sizeof(datsize) + datasize;
+	ssize_t sent = writev(net, v_data, 5);
+	if(sent != total) {
+		perror("E: couldn't write enough data:");
+	}
 }
 
 static CLIENT* handle_export_name(uint32_t opt, int net, GArray* servers, uint32_t cflags) {
@@ -1836,6 +1842,7 @@ int set_peername(int net, CLIENT *client) {
 			msg(LOG_DEBUG, "virtstyle cidr %d", client->server->cidrlen);
 			memcpy(&netaddr, &(client->clientaddr), addrinlen);
 			int addrbits;
+			assert((ai->ai_family == AF_INET) || (ai->ai_family == AF_INET6));
 			if(ai->ai_family == AF_INET) {
 				addrbits = 32;
 			} else if(ai->ai_family == AF_INET6) {
